==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/StepLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { StepLineSeriesDescription } from "./StepLineSeriesDescription";
/**
 * @hidden
 */
export let StepLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StepLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StepLineSeriesDescriptionMetadata.a == null) {
                StepLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StepLineSeriesDescriptionMetadata.c(StepLineSeriesDescriptionMetadata.a);
            }
            if (a.j(StepLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(StepLineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            StepLineSeriesDescriptionMetadata.b(a);
            a.aa("StepLineSeries", () => new StepLineSeriesDescription());
            a.z("StepLineSeries", StepLineSeriesDescriptionMetadata.a);
        }
    }
    StepLineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(StepLineSeriesDescriptionMetadata, 'StepLineSeriesDescriptionMetadata');
    StepLineSeriesDescriptionMetadata.a = null;
    return StepLineSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/StepLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { StepLineSeriesDescription } from "./StepLineSeriesDescription";
/**
 * @hidden
 */
export let StepLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StepLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StepLineSeriesDescriptionMetadata.a == null) {
                StepLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StepLineSeriesDescriptionMetadata.c(StepLineSeriesDescriptionMetadata.a);
            }
            if (a.k(StepLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(StepLineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            StepLineSeriesDescriptionMetadata.b(a);
            a.ac("StepLineSeries", () => new StepLineSeriesDescription());
            a.ab("StepLineSeries", StepLineSeriesDescriptionMetadata.a);
        }
    }
    StepLineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(StepLineSeriesDescriptionMetadata, 'StepLineSeriesDescriptionMetadata');
    StepLineSeriesDescriptionMetadata.a = null;
    return StepLineSeriesDescriptionMetadata;
})();
